# Generated by Django 5.1.4 on 2024-12-31 20:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cjkcms', '0022_cjkcmspage_breadcrumb_label_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='navbar',
            name='language',
            field=models.CharField(blank=True, choices=[], default='_all_', help_text='Select a language to limit display to specific locale.', max_length=10, verbose_name='Show in language'),
        ),
    ]
